==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/dd/d70/structCYapfNodeT.js <==
var structCYapfNodeT =
[
    [ "Key", "dd/d70/structCYapfNodeT.html#ab49bf18c412fa8ba308346bad96a43f9", null ],
    [ "Node", "dd/d70/structCYapfNodeT.html#ae797c27caa915fa53faee2bcd613a39c", null ],
    [ "Dump", "dd/d70/structCYapfNodeT.html#a98b79435c7d0e383755b788dec110fd9", null ],
    [ "GetCost", "dd/d70/structCYapfNodeT.html#a7f3101587e2ff6749b6b0df0fe5adbd3", null ],
    [ "GetCostEstimate", "dd/d70/structCYapfNodeT.html#ac69eb188d9fb443918571f10cf74e2c0", null ],
    [ "GetHashNext", "dd/d70/structCYapfNodeT.html#a4ca21507246c0c4cb2823e1c9e7c4336", null ],
    [ "GetKey", "dd/d70/structCYapfNodeT.html#a4c33f7f2b1e6c25c30c29c48a2a5a133", null ],
    [ "GetTile", "dd/d70/structCYapfNodeT.html#a21b2c6ddc5d3524e55aaac3cd5335aba", null ],
    [ "GetTrackdir", "dd/d70/structCYapfNodeT.html#aa734e4bc2ea85310d5cbefe4ec005e0b", null ],
    [ "operator<", "dd/d70/structCYapfNodeT.html#aab21f03e243f474c3b7bf6db778d55d8", null ],
    [ "Set", "dd/d70/structCYapfNodeT.html#a20c2fe468d5222faa5179dc0013879dd", null ],
    [ "SetHashNext", "dd/d70/structCYapfNodeT.html#a416064cac73010c801b0b32f5a1e8861", null ],
    [ "m_cost", "dd/d70/structCYapfNodeT.html#a49a51972f179399979170df663c048e1", null ],
    [ "m_estimate", "dd/d70/structCYapfNodeT.html#ab53afeea0ec9e41309394dfc15b6b59d", null ],
    [ "m_hash_next", "dd/d70/structCYapfNodeT.html#aa016dc07eb512b02fcb3053983b65012", null ],
    [ "m_key", "dd/d70/structCYapfNodeT.html#ae689e93791f926048d712fb1fa671ac7", null ],
    [ "m_parent", "dd/d70/structCYapfNodeT.html#af9cdb8abd434ea7e06b12e62b57f6e47", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/dd/d70/structCYapfNodeT.js <==
var structCYapfNodeT =
[
    [ "Key", "dd/d70/structCYapfNodeT.html#ab49bf18c412fa8ba308346bad96a43f9", null ],
    [ "Node", "dd/d70/structCYapfNodeT.html#ae797c27caa915fa53faee2bcd613a39c", null ],
    [ "Dump", "dd/d70/structCYapfNodeT.html#a98b79435c7d0e383755b788dec110fd9", null ],
    [ "GetCost", "dd/d70/structCYapfNodeT.html#a7f3101587e2ff6749b6b0df0fe5adbd3", null ],
    [ "GetCostEstimate", "dd/d70/structCYapfNodeT.html#ac69eb188d9fb443918571f10cf74e2c0", null ],
    [ "GetHashNext", "dd/d70/structCYapfNodeT.html#a4ca21507246c0c4cb2823e1c9e7c4336", null ],
    [ "GetIsChoice", "dd/d70/structCYapfNodeT.html#ab380591a006fa4c5ba20b5ca080f30d9", null ],
    [ "GetKey", "dd/d70/structCYapfNodeT.html#a4c33f7f2b1e6c25c30c29c48a2a5a133", null ],
    [ "GetTile", "dd/d70/structCYapfNodeT.html#a21b2c6ddc5d3524e55aaac3cd5335aba", null ],
    [ "GetTrackdir", "dd/d70/structCYapfNodeT.html#aa734e4bc2ea85310d5cbefe4ec005e0b", null ],
    [ "operator<", "dd/d70/structCYapfNodeT.html#aab21f03e243f474c3b7bf6db778d55d8", null ],
    [ "Set", "dd/d70/structCYapfNodeT.html#a20c2fe468d5222faa5179dc0013879dd", null ],
    [ "SetHashNext", "dd/d70/structCYapfNodeT.html#a416064cac73010c801b0b32f5a1e8861", null ],
    [ "m_cost", "dd/d70/structCYapfNodeT.html#a49a51972f179399979170df663c048e1", null ],
    [ "m_estimate", "dd/d70/structCYapfNodeT.html#ab53afeea0ec9e41309394dfc15b6b59d", null ],
    [ "m_hash_next", "dd/d70/structCYapfNodeT.html#aa016dc07eb512b02fcb3053983b65012", null ],
    [ "m_is_choice", "dd/d70/structCYapfNodeT.html#ae4a647195858ddbb4150c1041734c028", null ],
    [ "m_key", "dd/d70/structCYapfNodeT.html#ae689e93791f926048d712fb1fa671ac7", null ],
    [ "m_parent", "dd/d70/structCYapfNodeT.html#af9cdb8abd434ea7e06b12e62b57f6e47", null ]
];
